@@ -2,7 +2,7 @@
 #
 # The fisx library for X-Ray Fluorescence
 #
-# Copyright (c) 2014-2017 European Synchrotron Radiation Facility
+# Copyright (c) 2014-2018 European Synchrotron Radiation Facility
 #
 # This file is part of the fisx X-ray developed by V.A. Sole
 #
@@ -533,6 +533,7 @@ std::map<std::string, std::pair<double, int> > \
         }
     }
 
+    /*
     if (false)
     {
         for (result_it = result.begin(); result_it != result.end(); ++result_it)
@@ -542,6 +543,7 @@ std::map<std::string, std::pair<double, int> > \
             std::cout << this->name << " Found shell " << key << " at " << energy << std::endl;
         }
     }
+    */
     return result;
 }
 
@@ -1280,10 +1282,9 @@ Element::getXRayLinesFromVacancyDistribution(const std::map<std::string, double>
                 if (cacheKey == cascadeCache.end())
                 {
                     std::cout << this->name << " Error processing vacancy on shell " << c_it->first << std::endl;
-                    throw std::runtime_error("Vacancy on a shell not present in the cache!");
+                    throw std::runtime_error("Vacancy in a shell not present in the cache!");
                     // the above is not good, there can be no emission following a vacancy (rate too low)
                     // it seems to be triggered by As L1 vacancies
-                    continue;
                 }
                 for(std::map<std::string, std::map<std::string, double> >::const_iterator rayIt = \
                     cacheKey->second.begin(); rayIt != cacheKey->second.end(); ++rayIt)
@@ -1657,6 +1658,7 @@ void Element::clearCache()
 void Element::fillCache(const std::vector<double> & energy)
 {
     std::vector<double>::size_type i, maxSize;
+    int status;
 
     this->clearCache();
 
@@ -1668,31 +1670,58 @@ void Element::fillCache(const std::vector<double> & energy)
     {
         maxSize = this->cacheMaximumSize;
     }
-    for (i = 0; i < maxSize; i++)
+    status = this->isCacheEnabled();
+    try
     {
-        this->muCache[energy[i]] = this->getMassAttenuationCoefficients(energy[i]);
-        this->excitationFactorsCache[energy[i]] = this->getPhotoelectricExcitationFactors(energy[i], 1.0);
+        // This is necessary because clang pushes return value optimization to the limit
+        // and creates the key into muCache prior to call getMassAttenuationCoefficients
+        this->setCacheEnabled(0);
+        for (i = 0; i < maxSize; i++)
+        {
+            this->muCache[energy[i]] = this->getMassAttenuationCoefficients(energy[i]);
+            this->excitationFactorsCache[energy[i]] = this->getPhotoelectricExcitationFactors(energy[i], 1.0);
+        }
+        this->setCacheEnabled(status);
+    }
+    catch(...)
+    {
+        this->setCacheEnabled(status);
+        throw;
     }
 }
 
 void Element::updateCache(const std::vector< double> & energy)
 {
     std::vector<double>::size_type i, eSize;
+    int status;
 
+    // This is necessary because clang pushes return value optimization to the limit
+    // and creates the key into muCache prior to call getMassAttenuationCoefficients
+    status = this->isCacheEnabled();
+    this->setCacheEnabled(0);
     eSize = energy.size();
-    for (i = 0; i < eSize; i++)
+    try
     {
-        if (this->muCache.size() < this->cacheMaximumSize)
+        for (i = 0; i < eSize; i++)
         {
-            if (this->muCache.find(energy[i]) == this->muCache.end())
+            if (this->muCache.size() < this->cacheMaximumSize)
             {
-                this->muCache[energy[i]] = this->getMassAttenuationCoefficients(energy[i]);
-            }
-            if (this->excitationFactorsCache.find(energy[i]) == this->excitationFactorsCache.end())
-            {
-                this->excitationFactorsCache[energy[i]] = this->getPhotoelectricExcitationFactors(energy[i], 1.0);
+                if (this->muCache.find(energy[i]) == this->muCache.end())
+                {
+                    this->muCache[energy[i]] = this->getMassAttenuationCoefficients(energy[i]);
+                }
+                if (this->excitationFactorsCache.find(energy[i]) == this->excitationFactorsCache.end())
+                {
+                    this->excitationFactorsCache[energy[i]] = this->getPhotoelectricExcitationFactors(energy[i], 1.0);
+                }
             }
         }
+        this->setCacheEnabled(status);
+    }
+    catch(...)
+    {
+        this->setCacheEnabled(status);
+        throw;
     }
     if (this->muCache.size() >= this->cacheMaximumSize)
     {
